/*
 * Version: 1.0
 *
 * The contents of this file are subject to the OpenVPMS License Version
 * 1.0 (the 'License'); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.openvpms.org/license/
 *
 * Software distributed under the License is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright 2016 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.report.jasper;

import org.apache.commons.jxpath.Functions;
import org.junit.Test;
import org.openvpms.archetype.test.TestHelper;
import org.openvpms.component.business.domain.im.common.IMObject;
import org.openvpms.component.business.domain.im.party.Party;
import org.openvpms.component.business.service.archetype.helper.ResolvingPropertySet;
import org.openvpms.component.system.common.util.PropertySet;

import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.junit.Assert.assertTrue;

/**
 * Tests the {@link IMObjectCollectionDataSource} class.
 *
 * @author Tim Anderson
 */
public class IMObjectCollectionDataSourceTestCase extends AbstractIMObjectDataSourceTestCase {

    /**
     * Tests the {@link IMObjectCollectionDataSource#getExpressionDataSource(String)} method.
     *
     * @throws Exception for any error
     */
    @Test
    public void testExpressionDataSource() throws Exception {
        Party customer = TestHelper.createCustomer(false);
        List<IMObject> objects = Collections.<IMObject>singletonList(customer);
        Map<String, Object> fields = new HashMap<>();
        fields.put("Globals.A", "A");
        fields.put("Globals.1", 1);
        PropertySet f = new ResolvingPropertySet(fields, getArchetypeService(), getLookupService());
        Functions functions = applicationContext.getBean(Functions.class);
        IMObjectCollectionDataSource ds = new IMObjectCollectionDataSource(objects, null, f, getArchetypeService(),
                                                                           getLookupService(), handlers, functions);
        assertTrue(ds.next());
        checkExpressionDataSource(ds, f);
    }

}
