/*
 *  Version: 1.0
 *
 *  The contents of this file are subject to the OpenVPMS License Version
 *  1.0 (the 'License'); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *  http://www.openvpms.org/license/
 *
 *  Software distributed under the License is distributed on an 'AS IS' basis,
 *  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 *  for the specific language governing rights and limitations under the
 *  License.
 *
 *  Copyright 2006 (C) OpenVPMS Ltd. All Rights Reserved.
 */

package org.openvpms.web.component.im.print;

import org.openvpms.archetype.rules.doc.DocumentTemplate;
import org.openvpms.component.business.domain.im.common.IMObject;
import org.openvpms.component.system.common.exception.OpenVPMSException;
import org.openvpms.report.IMReport;
import org.openvpms.web.component.app.Context;
import org.openvpms.web.component.im.report.ContextDocumentTemplateLocator;
import org.openvpms.web.component.im.report.DocumentTemplateLocator;
import org.openvpms.web.component.im.report.IMObjectReporter;
import org.openvpms.web.component.im.report.ReporterFactory;
import org.openvpms.web.component.im.report.TemplatedReporter;


/**
 * Prints reports for {@link IMObject}s generated by {@link IMReport}.
 *
 * @author Tim Anderson
 */
public class IMObjectReportPrinter<T extends IMObject> extends TemplatedIMPrinter<T> {

    /**
     * Constructs an {@code IMObjectReportPrinter}.
     *
     * @param object  the object to print
     * @param locator the document template locator
     * @param context the context
     * @throws OpenVPMSException for any error
     */
    public IMObjectReportPrinter(T object, DocumentTemplateLocator locator, Context context) {
        super(ReporterFactory.<T, TemplatedReporter<T>>create(object, locator, TemplatedReporter.class), context);
    }

    /**
     * Constructs an {@code IMObjectReportPrinter}.
     *
     * @param object   the object to print
     * @param template the document template to use
     * @param context  the context
     * @throws OpenVPMSException for any error
     */
    public IMObjectReportPrinter(T object, DocumentTemplate template, Context context) {
        super(ReporterFactory.<T, TemplatedReporter<T>>create(object, template, TemplatedReporter.class), context);
    }

    /**
     * Constructs an {@code IMObjectReportPrinter} to print a collection of objects.
     *
     * @param objects  the objects to print
     * @param template the document template to use
     * @param context  the context
     * @throws OpenVPMSException for any error
     */
    public IMObjectReportPrinter(Iterable<T> objects, DocumentTemplate template, Context context) {
        super(ReporterFactory.<T, TemplatedReporter<T>>create(objects, template, TemplatedReporter.class), context);
    }

    /**
     * Constructs an {@code IMObjectReportPrinter} to print a collection of objects.
     *
     * @param objects the objects to print
     * @param locator the document template locator
     * @param context the context
     * @throws OpenVPMSException for any error
     */
    public IMObjectReportPrinter(Iterable<T> objects, DocumentTemplateLocator locator, Context context) {
        super(ReporterFactory.<T, TemplatedReporter<T>>create(objects, locator, TemplatedReporter.class), context);
    }

    /**
     * Constructs an {@code IMObjectReportPrinter} to print a collection of objects.
     *
     * @param objects   the objects to print
     * @param shortName the archetype short name to determine the template to use
     * @param context   the context
     * @throws OpenVPMSException for any error
     */
    public IMObjectReportPrinter(Iterable<T> objects, String shortName, Context context) {
        super(new IMObjectReporter<T>(objects, new ContextDocumentTemplateLocator(shortName, context)), context);
    }

}
